@@ -70,7 +70,7 @@ class BackupThread(QtCore.QThread):
 
 class BackupVMsWindow(ui_backupdlg.Ui_Backup, QtWidgets.QWizard):
     def __init__(self, qt_app, qubes_app, dispatcher, parent=None):
-        super(BackupVMsWindow, self).__init__(parent)
+        super().__init__(parent)
 
         self.qt_app = qt_app
         self.qubes_app = qubes_app
@@ -121,6 +121,9 @@ class BackupVMsWindow(ui_backupdlg.Ui_Backup, QtWidgets.QWizard):
         self.unrecognized_config_label.setVisible(False)
         self.load_settings()
 
+        self.show_passwd_button.pressed.connect(self.show_password)
+        self.show_passwd_button.released.connect(self.hide_password)
+
         selected = self.vms_to_include()
         self.__fill_vms_list__(selected)
 
@@ -130,6 +133,14 @@ class BackupVMsWindow(ui_backupdlg.Ui_Backup, QtWidgets.QWizard):
         self.dispatcher = dispatcher
         dispatcher.add_handler('backup-progress', self.on_backup_progress)
 
+    def show_password(self):
+        self.passphrase_line_edit.setEchoMode(QtWidgets.QLineEdit.Normal)
+        self.show_passwd_button.setIcon(QtGui.QIcon(':/eye.svg'))
+
+    def hide_password(self):
+        self.passphrase_line_edit.setEchoMode(QtWidgets.QLineEdit.Password)
+        self.show_passwd_button.setIcon(QtGui.QIcon(':/eye-off.svg'))
+
     def setup_application(self):
         self.qt_app.setApplicationName(self.tr("Qubes Backup VMs"))
         self.qt_app.setWindowIcon(QtGui.QIcon.fromTheme("qubes-manager"))
