@@ -30,8 +30,10 @@ import traceback
 from qubesadmin.tools import QubesArgumentParser
 from qubesadmin import devices
 from qubesadmin import utils as admin_utils
+from qubesadmin.tools import qvm_start
 import qubesadmin.exc
 
+from . import bootfromdevice
 from . import utils
 from . import multiselectwidget
 from . import common_threads
@@ -627,14 +629,22 @@ class VMSettingsWindow(ui_settingsdlg.Ui_SettingsDialog, QtWidgets.QDialog):
             self.warn_too_much_mem_label.setVisible(True)
 
     def check_warn_templatenetvm(self):
-        if self.vm.klass == 'TemplateVM':
+        if self.vm.klass != 'TemplateVM':
+            return
+
+        current_netvm = self.netVM.currentData()
+        if current_netvm is None:
+            return
+
+        if current_netvm != qubesadmin.DEFAULT:
             QtWidgets.QMessageBox.warning(
                 self,
                 self.tr("Warning!"),
-                self.tr("Connecting a TemplateVM directly to a network is higly"
-                        " discouraged! <br> <small>You are breaking a basic par"
-                        "t of Qubes security and there is probably no real need"
-                        " to do so. Continue at your own risk.</small>"))
+                self.tr(
+                    "Connecting a TemplateVM directly to a network is highly"
+                    " discouraged! <br> <small>You are breaking a basic part "
+                    "of Qubes security and there is probably no real need"
+                    " to do so. Continue at your own risk.</small>"))
 
     def check_warn_dispvmnetvm(self):
         if not hasattr(self.vm, 'default_dispvm'):
@@ -1022,8 +1032,12 @@ class VMSettingsWindow(ui_settingsdlg.Ui_SettingsDialog, QtWidgets.QDialog):
             self.check_mem_changes()
 
     def boot_from_cdrom_button_pressed(self):
-        self.save_and_apply()
-        subprocess.check_call(['qubes-vm-boot-from-device', self.vm.name])
+        boot_dialog = bootfromdevice.VMBootFromDeviceWindow(
+                self.vm.name, self.qapp, self.qubesapp, self)
+        if boot_dialog.exec_():
+            self.save_and_apply()
+            qvm_start.main(
+                    ['--cdrom', boot_dialog.cdrom_location, self.vm.name])
 
     def virt_mode_changed(self, new_idx):  # pylint: disable=unused-argument
         self.update_pv_warning()
